@@ -243,7 +243,7 @@ class Query:
                                  "int1", "ubigint", "uinteger", "usmallint",
                                  "utinyint", "bool", "boolean", "mediumint",
                                  "double precision", "dec", "smallserial", "serial",
-                                 "bigserial", "number", "binary", "smalldecimal"],
+                                 "bigserial", "number", "number(3,2)", "binary", "smalldecimal"],
                             "date":
                                 ["date", "datetimeoffset", "datetime2", "smalldatetime",
                                  "timestamp", "datetime", "time", "year",
